<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:output method="xhtml:xhtml"/>


<!-- INTERFACE -->
<xsl:template name="interface">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <html>
    <head>
      <title> Interface <xsl:value-of select="@name"/> </title>
      <link href="../global.css" rel="stylesheet" type="text/css" />
      <link href="../reference.css" rel="stylesheet" type="text/css" />
      <link href="../example.css" rel="stylesheet" type="text/css" />
    </head>
    <body>
    
      <!-- HEADER -->
      <xsl:call-template name="header">
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="interface"><xsl:value-of select="@name"/></xsl:with-param>
        <xsl:with-param name="property">null</xsl:with-param>
      </xsl:call-template>
      
      <!-- INTERFACE body -->
      <h2>
        <xsl:value-of select="@name"/>
        (interface
        <xsl:if test="@deprecated='yes'">
          <xsl:text>,&#160;</xsl:text>
          <span class="deprecated">deprecated in HTML 4.01</span>
        </xsl:if>
        )
      </h2>

    <xsl:if test="$module='Core'">
      <div>
        <span class="bold2">Type of the interface: </span>
        &#160; <a href="../_glossary.html#{@type}" class="code"><xsl:value-of select="@type"/></a>
      </div>
    </xsl:if>

      <br />
      <div>
        <span class="bold2">Own properties: </span>
      </div>
      <table class="inner" border="0" cellspacing="0">
        <tr align="left" valign="top">
          <td class="bold2">attributes</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:choose>
              <xsl:when test="attribute">
                <xsl:apply-templates select="attribute" mode="list">
                  <xsl:sort select="@name"/>
                </xsl:apply-templates>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>none</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr><tr align="left" valign="top">
          <td class="bold2">methods</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:choose>
              <xsl:when test="method">
                <xsl:apply-templates select="method" mode="list">
                  <xsl:sort select="@name"/>
                </xsl:apply-templates>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>none</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </table>

  <xsl:if test="@inherits">
  <xsl:choose>
    <xsl:when test="not($module='HTML') or ( ($module='HTML') and ( (@inherits='Document') or (@inherits='Element') ) )">
      <br />
      <div>
        <span class="bold2">Inherited properties: </span>
      </div>
      <table class="inner" border="0" cellspacing="0">
        <tr align="left" valign="top">
          <td class="bold2">attributes</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:apply-templates select="key('interface',@inherits)/parent::*/attribute | key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/attribute | key('interface',key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/@inherits)/parent::*/attribute" mode="list">
              <xsl:with-param name="inherited">yes</xsl:with-param>
              <xsl:with-param name="inheritedFor"><xsl:value-of select="$module"/></xsl:with-param>
            </xsl:apply-templates>
          </td>
        </tr><tr align="left" valign="top">
          <td class="bold2">methods</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:apply-templates select="key('interface',@inherits)/parent::*/method | key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/method | key('interface',key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/@inherits)/parent::*/method" mode="list">
              <xsl:with-param name="inherited">yes</xsl:with-param>
              <xsl:with-param name="inheritedFor"><xsl:value-of select="$module"/></xsl:with-param>
            </xsl:apply-templates>
          </td>
        </tr>
      </table>
    </xsl:when>
    <xsl:otherwise>	<!-- so it's the interface from module HTML which inherits all the stuff from HTMLElement -->
      <br />
      <div>
        <span class="bold2">Inherited properties: </span>
      </div>
      <table class="inner" border="0" cellspacing="0">
        <tr align="left" valign="top">
          <td>
            This interface inherits all properties from <a href="interface_HTMLElement.html" class="interface">HTMLElement</a>, the generic interface for all element interfaces in DOM HTML, which itself inherits all properties from DOM Core interface <a href="../Core/interface_Element.html" class="interface">Element</a> and thus also <a href="../Core/interface_Node.html" class="interface">Node</a>.
          </td>
        </tr>
      </table>
    </xsl:otherwise>
  </xsl:choose>
  </xsl:if>

      <br />
      <div class="bold1">Description: </div>
      <div class="dataBody">
        <xsl:apply-templates select="description">
          <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        </xsl:apply-templates>
      </div>

      <xsl:if test="note">
        <br />
        <div class="bold1">Note: </div>
        <div class="dataBody">
          <xsl:apply-templates select="note">
            <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
          </xsl:apply-templates>
        </div>
      </xsl:if>

      <xsl:if test="group">
        <br />
        <xsl:apply-templates select="group"/>
      </xsl:if>

      <!-- FOOTER -->
      <xsl:call-template name="footer"/>

    </body>
  </html>
</xsl:template>

<xsl:template match="attribute" mode="list">
  <xsl:param name="inherited">no</xsl:param>
  <xsl:param name="inheritedFor"/>
  <xsl:variable name="prePath">
    <xsl:choose>
      <xsl:when test="$inheritedFor='HTML'"><xsl:text>../Core/</xsl:text></xsl:when>
      <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="whichClass"><xsl:value-of select="name()"/>Fg</xsl:variable>
  <a class="{$whichClass}" href="{$prePath}attribute_{@name}_{../@name}.html">
    <xsl:if test="$inherited = 'yes'">
      <xsl:attribute name="title">inherited from <xsl:value-of select="parent::interface/@name"/></xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@name"/>
  </a>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>
<xsl:template match="method" mode="list">
  <xsl:param name="inherited">no</xsl:param>
  <xsl:param name="inheritedFor"/>
  <xsl:variable name="prePath">
    <xsl:choose>
      <xsl:when test="$inheritedFor='HTML'"><xsl:text>../Core/</xsl:text></xsl:when>
      <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="whichClass"><xsl:value-of select="name()"/>Fg</xsl:variable>
  <a class="{$whichClass}" href="{$prePath}method_{@name}_{../@name}.html">
    <xsl:if test="$inherited = 'yes'">
      <xsl:attribute name="title">inherited from <xsl:value-of select="parent::interface/@name"/></xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@name"/>
  </a>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>

</xsl:stylesheet>
